/* 
 * TCS Alignment Toolbox
 * 
 * Copyright (C) 2013, 2014
 * Benjamin Paaßen, Charlie Krüger, Georg Zentgraf
 * AG Theoretical Computer Science
 * Centre of Excellence Cognitive Interaction Technology (CITEC)
 * University of Bielefeld
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.citec.tcs.alignment.comparators;

/**
 * This normalizes by using the function 1-exp(-beta*d)
 *
 * @author Benjamin Paassen - bpaassen@techfak.uni-bielefeld.de
 */
public class ExponentialNormalizer implements Normalizer {

    private double beta = 0.5;

    public ExponentialNormalizer(double beta) {
        this.beta = beta;
    }

    public ExponentialNormalizer() {
    }

    /**
     *
     * @param beta the slope of the exponential.
     */
    public void setBeta(double beta) {
        this.beta = beta;
    }

    /**
     *
     * @return the slope of the exponential.
     */
    public double getBeta() {
        return beta;
    }

    /**
     * {@inheritDoc }
     */
    @Override
    public double normalize(double distance) {
        return 1 - Math.exp(-beta * distance);
    }

    /**
     * {@inheritDoc }
     */
    @Override
    public int hashCode() {
        int hash = 7;
        hash = 23 * hash
                + (int) (Double.doubleToLongBits(this.beta)
                ^ (Double.doubleToLongBits(this.beta) >>> 32));
        return hash;
    }

    /**
     * {@inheritDoc }
     */
    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final ExponentialNormalizer other = (ExponentialNormalizer) obj;
        if (Double.doubleToLongBits(this.beta) != Double.doubleToLongBits(other.beta)) {
            return false;
        }
        return true;
    }
}
