/*
 * TCS Alignment Toolbox
 * 
 * Copyright (C) 2013, 2014
 * Benjamin Paaßen, Charlie Krüger, Georg Zentgraf
 * AG Theoretical Computer Science
 * Centre of Excellence Cognitive Interaction Technology (CITEC)
 * University of Bielefeld
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package de.unibi.citec.tcs.alignment;

import de.unibi.citec.tcs.alignment.sequence.Sequence;
import de.unibi.citec.tcs.alignment.wrappers.VectorialSequences;
import java.util.Arrays;
import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import static org.junit.Assert.*;

/**
 *
 * @author Benjamin Paassen - bpaassen@techfak.uni-bielefeld.de
 */
public class StrictDTWFullAlgorithmTest {

	public StrictDTWFullAlgorithmTest() {
	}

	@BeforeClass
	public static void setUpClass() {
	}

	@AfterClass
	public static void tearDownClass() {
	}

	@Before
	public void setUp() {
	}

	@After
	public void tearDown() {
	}

	/**
	 * Test of transformToResult method, of class StrictDTWFullAlgorithm.
	 */
	@Test
	public void testTransformToResult() {
		final int numSamples = 100;
		final double f1 = 0.1;
		final double f2 = 0.07;
		//create two sine waves with different frequencies.
		final double[][] waves = new double[2][numSamples];
		for (int i = 0; i < numSamples; i++) {
			waves[0][i] = Math.sin(Math.PI * f1 * i);
			waves[1][i] = Math.sin(Math.PI * f2 * i);
		}
		//transform them to sequences.
		final Sequence[] seqs = VectorialSequences.toSequences(waves);
		//create AlignmentSpecification.
		final AlignmentSpecification spec = VectorialSequences.setUpSpecification(seqs);
		//set up algorithm.
		final StrictDTWFullAlgorithm instance = new StrictDTWFullAlgorithm(spec);
		//look at alignment path.
		final AlignmentPath path = instance.calculateAlignment(seqs[0], seqs[1]);
		assertTrue(path.getOperations().size() >= numSamples);
		assertTrue(path.getOperations().size() < numSamples * 2);
	}

}
