/* 
 * TCS Alignment Toolbox
 * 
 * Copyright (C) 2013, 2014
 * Benjamin Paaßen, Charlie Krüger, Georg Zentgraf
 * AG Theoretical Computer Science
 * Centre of Excellence Cognitive Interaction Technology (CITEC)
 * University of Bielefeld
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.citec.tcs.alignment.sequence;

import java.util.HashMap;
import junit.framework.TestCase;

/**
 *
 * @author Benjamin Paassen - bpaassen@techfak.uni-bielefeld.de
 */
public class AlphabetTest extends TestCase {

	public AlphabetTest(String testName) {
		super(testName);
	}

	@Override
	protected void setUp() throws Exception {
		super.setUp();
	}

	@Override
	protected void tearDown() throws Exception {
		super.tearDown();
	}

	/**
	 * Test of constructors of class Alphabet.
	 */
	public void testConstructors() {
		final String[] symbols = {"3", "4.2", "test"};
		Alphabet instance = new Alphabet(symbols);
		checkAlphabet(symbols, instance);

		final HashMap<String, Integer> mapping = new HashMap<String, Integer>();
		for (int i = 0; i < symbols.length; i++) {
			mapping.put(symbols[i], i);
		}
		instance = new Alphabet(mapping);
		checkAlphabet(symbols, instance);

		final String symbolStr = "abcd";
		final String[] expected = {"a", "b", "c", "d"};
		instance = new Alphabet(symbolStr);
		checkAlphabet(expected, instance);
		instance = new Alphabet(symbolStr);
		checkAlphabet(expected, instance);

		final String delimSymbolStr = "|one|two|three|";
		instance = new Alphabet(delimSymbolStr);
		checkAlphabet(new String[]{"one", "two", "three"}, instance);
	}

	private static void checkAlphabet(final String[] expectedSymbols, final Alphabet actual) {
		assertEquals(expectedSymbols.length, actual.getSymbols().length);
		assertEquals(expectedSymbols.length, actual.size());
		for (int i = 0; i < expectedSymbols.length; i++) {
			assertEquals(expectedSymbols[i], actual.getSymbol(i));
			assertEquals(i, actual.getSymbolIndex(expectedSymbols[i]));
			assertEquals(expectedSymbols[i], actual.getSymbols()[i]);
		}
	}

	/**
	 * Test of toString method, of class Alphabet.
	 */
	public void testToString() {
		final String symbolStr = "one|two|three";
		final Alphabet instance = new Alphabet(symbolStr);
		assertEquals(symbolStr, instance.toString());
	}
}
